@@ -3,10 +3,10 @@
 require 'yaml'
 require 'json'
 require 'tmpdir'
-require 'readline'
 
 require 'chake/version'
 require 'chake/node'
+require 'chake/readline'
 
 nodes_file = ENV['CHAKE_NODES'] || 'nodes.yaml'
 node_data = File.exists?(nodes_file) && YAML.load_file(nodes_file) || {}
@@ -192,7 +192,13 @@ $nodes.each do |node|
 end
 
 task :run_input do
-  $cmd = ENV['CMD'] || Readline.readline('$ ')
+  puts "# Enter command to run (use arrow keys for history):"
+  $cmd = ENV['CMD'] || Chake::Readline.readline
+  if !$cmd || $cmd.strip == ''
+    puts
+    puts "I: no command provided, operation aborted."
+    exit(1)
+  end
 end
 
 desc "upload to all nodes"
